@@ -675,6 +675,11 @@ static int str_verify_pattern_cb(void *data, const char *input)
 		}
 	}
 	td->o.verify_pattern_bytes = i;
+	/*
+	 * VERIFY_META could already be set
+	 */
+	if (td->o.verify == VERIFY_NONE)
+		td->o.verify = VERIFY_PATTERN;
 	return 0;
 }
 
@@ -913,7 +918,7 @@ static struct fio_option options[FIO_MAX_OPTS] = {
 		.type	= FIO_OPT_STR_STORE,
 		.off1	= td_var_offset(ioengine),
 		.help	= "IO engine to use",
-		.def	= "sync",
+		.def	= FIO_PREFERRED_ENGINE,
 		.posval	= {
 			  { .ival = "sync",
 			    .help = "Use read/write",
@@ -922,7 +927,7 @@ static struct fio_option options[FIO_MAX_OPTS] = {
 			    .help = "Use pread/pwrite",
 			  },
 			  { .ival = "vsync",
-			     .help = "Use readv/writev",
+			    .help = "Use readv/writev",
 			  },
 #ifdef FIO_HAVE_LIBAIO
 			  { .ival = "libaio",
@@ -938,9 +943,14 @@ static struct fio_option options[FIO_MAX_OPTS] = {
 			  { .ival = "solarisaio",
 			    .help = "Solaris native asynchronous IO",
 			  },
+#endif
+#ifdef FIO_HAVE_WINDOWSAIO
+			  { .ival = "windowsaio",
+			    .help = "Windows native asynchronous IO"
+		  	  },
 #endif
 			  { .ival = "mmap",
-			    .help = "Memory mapped IO",
+			    .help = "Memory mapped IO"
 			  },
 #ifdef FIO_HAVE_SPLICE
 			  { .ival = "splice",
@@ -967,7 +977,7 @@ static struct fio_option options[FIO_MAX_OPTS] = {
 			  },
 #endif
 			  { .ival = "cpuio",
-			    .help = "CPU cycler burner engine",
+			    .help = "CPU cycle burner engine",
 			  },
 #ifdef FIO_HAVE_GUASI
 			  { .ival = "guasi",
@@ -988,7 +998,7 @@ static struct fio_option options[FIO_MAX_OPTS] = {
 		.name	= "iodepth",
 		.type	= FIO_OPT_INT,
 		.off1	= td_var_offset(iodepth),
-		.help	= "Amount of IO buffers to keep in flight",
+		.help	= "Number of IO buffers to keep in flight",
 		.minval = 1,
 		.def	= "1",
 	},
@@ -1027,6 +1037,7 @@ static struct fio_option options[FIO_MAX_OPTS] = {
 	},
 	{
 		.name	= "fill_device",
+		.alias	= "fill_fs",
 		.type	= FIO_OPT_BOOL,
 		.off1	= td_var_offset(fill_device),
 		.help	= "Write until an ENOSPC error occurs",
@@ -1121,6 +1132,7 @@ static struct fio_option options[FIO_MAX_OPTS] = {
 	},
 	{
 		.name	= "nrfiles",
+		.alias	= "nr_files",
 		.type	= FIO_OPT_INT,
 		.off1	= td_var_offset(nr_files),
 		.help	= "Split job workload between this number of files",
@@ -1460,6 +1472,14 @@ static struct fio_option options[FIO_MAX_OPTS] = {
 		.help	= "Exit on a single verify failure, don't continue",
 		.parent = "verify",
 	},
+	{
+		.name	= "verify_dump",
+		.type	= FIO_OPT_BOOL,
+		.off1	= td_var_offset(verify_dump),
+		.def	= "1",
+		.help	= "Dump contents of good and bad blocks on failure",
+		.parent = "verify",
+	},
 	{
 		.name	= "verify_async",
 		.type	= FIO_OPT_INT,
@@ -1689,7 +1709,7 @@ static struct fio_option options[FIO_MAX_OPTS] = {
 		.type	= FIO_OPT_INT,
 		.off1	= td_var_offset(rate_iops_min[0]),
 		.off2	= td_var_offset(rate_iops_min[1]),
-		.help	= "Job must meet this rate or it will be shutdown",
+		.help	= "Job must meet this rate or it will be shut down",
 		.parent	= "rate_iops",
 	},
 	{
@@ -1734,7 +1754,7 @@ static struct fio_option options[FIO_MAX_OPTS] = {
 		.name	= "create_fsync",
 		.type	= FIO_OPT_BOOL,
 		.off1	= td_var_offset(create_fsync),
-		.help	= "Fsync file after creation",
+		.help	= "fsync file after creation",
 		.def	= "1",
 	},
 	{
@@ -1748,7 +1768,7 @@ static struct fio_option options[FIO_MAX_OPTS] = {
 		.name	= "pre_read",
 		.type	= FIO_OPT_BOOL,
 		.off1	= td_var_offset(pre_read),
-		.help	= "Preread files before starting official testing",
+		.help	= "Pre-read files before starting official testing",
 		.def	= "0",
 	},
 	{
@@ -1899,7 +1919,7 @@ static struct fio_option options[FIO_MAX_OPTS] = {
 		.name	= "disable_slat",
 		.type	= FIO_OPT_BOOL,
 		.off1	= td_var_offset(disable_slat),
-		.help	= "Disable submissionn latency numbers",
+		.help	= "Disable submission latency numbers",
 		.parent	= "gtod_reduce",
 		.def	= "0",
 	},
@@ -1915,14 +1935,14 @@ static struct fio_option options[FIO_MAX_OPTS] = {
 		.name	= "gtod_cpu",
 		.type	= FIO_OPT_INT,
 		.cb	= str_gtod_cpu_cb,
-		.help	= "Setup dedicated gettimeofday() thread on this CPU",
+		.help	= "Set up dedicated gettimeofday() thread on this CPU",
 		.verify	= gtod_cpu_verify,
 	},
 	{
 		.name	= "continue_on_error",
 		.type	= FIO_OPT_BOOL,
 		.off1	= td_var_offset(continue_on_error),
-		.help	= "Continue on non-fatal errors during I/O",
+		.help	= "Continue on non-fatal errors during IO",
 		.def	= "0",
 	},
 	{
